@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2015-2022 MinIO, Inc.
+// Copyright (c) 2015-2024 MinIO, Inc.
 //
 // This file is part of MinIO Object Storage stack
 //
@@ -101,6 +101,7 @@ type Options struct {
 }
 
 // New - instantiate minio admin client
+//
 // Deprecated: please use NewWithOptions
 func New(endpoint string, accessKeyID, secretAccessKey string, secure bool) (*AdminClient, error) {
 	creds := credentials.NewStaticV4(accessKeyID, secretAccessKey, "")
@@ -469,7 +470,7 @@ func (adm AdminClient) setUserAgent(req *http.Request) {
 
 // GetAccessAndSecretKey - retrieves the access and secret keys.
 func (adm AdminClient) GetAccessAndSecretKey() (string, string) {
-	value, err := adm.credsProvider.Get()
+	value, err := adm.credsProvider.GetWithContext(adm.CredContext())
 	if err != nil {
 		return "", ""
 	}
@@ -482,7 +483,7 @@ func (adm AdminClient) GetEndpointURL() *url.URL {
 }
 
 func (adm AdminClient) getSecretKey() string {
-	value, err := adm.credsProvider.Get()
+	value, err := adm.credsProvider.GetWithContext(adm.CredContext())
 	if err != nil {
 		// Return empty, call will fail.
 		return ""
@@ -513,7 +514,7 @@ func (adm AdminClient) newRequest(ctx context.Context, method string, reqData re
 		return nil, err
 	}
 
-	value, err := adm.credsProvider.Get()
+	value, err := adm.credsProvider.GetWithContext(adm.CredContext())
 	if err != nil {
 		return nil, err
 	}
@@ -563,3 +564,10 @@ func (adm AdminClient) makeTargetURL(r requestData) (*url.URL, error) {
 	}
 	return u, nil
 }
+
+// CredContext returns the context for fetching credentials
+func (adm AdminClient) CredContext() *credentials.CredContext {
+	return &credentials.CredContext{
+		Client: adm.httpClient,
+	}
+}
