@@ -20,8 +20,10 @@
 package madmin
 
 import (
+	"bytes"
 	"context"
 	"encoding/json"
+	"errors"
 	"io"
 	"net/http"
 	"net/url"
@@ -60,11 +62,14 @@ type ReplicateAddStatus struct {
 // SRAddOptions holds SR Add options
 type SRAddOptions struct {
 	ReplicateILMExpiry bool
+	Force              bool
 }
 
 func (o *SRAddOptions) getURLValues() url.Values {
 	urlValues := make(url.Values)
 	urlValues.Set("replicateILMExpiry", strconv.FormatBool(o.ReplicateILMExpiry))
+	urlValues.Set("force", strconv.FormatBool(o.Force))
+
 	return urlValues
 }
 
@@ -284,6 +289,25 @@ const (
 	SRIAMItemExternalUser  = "external-user"
 )
 
+// SRSessionPolicy - represents a session policy to be replicated.
+type SRSessionPolicy json.RawMessage
+
+func (s SRSessionPolicy) MarshalJSON() ([]byte, error) {
+	return json.RawMessage(s).MarshalJSON()
+}
+
+func (s *SRSessionPolicy) UnmarshalJSON(data []byte) error {
+	if s == nil {
+		return errors.New("json.RawMessage: UnmarshalJSON on nil pointer")
+	}
+	if bytes.Equal(data, []byte("null")) {
+		*s = nil
+	} else {
+		*s = append((*s)[0:0], data...)
+	}
+	return nil
+}
+
 // SRSvcAccCreate - create operation
 type SRSvcAccCreate struct {
 	Parent        string                 `json:"parent"`
@@ -291,7 +315,7 @@ type SRSvcAccCreate struct {
 	SecretKey     string                 `json:"secretKey"`
 	Groups        []string               `json:"groups"`
 	Claims        map[string]interface{} `json:"claims"`
-	SessionPolicy json.RawMessage        `json:"sessionPolicy"`
+	SessionPolicy SRSessionPolicy        `json:"sessionPolicy"`
 	Status        string                 `json:"status"`
 	Name          string                 `json:"name"`
 	Description   string                 `json:"description"`
@@ -306,7 +330,7 @@ type SRSvcAccUpdate struct {
 	Status        string          `json:"status"`
 	Name          string          `json:"name"`
 	Description   string          `json:"description"`
-	SessionPolicy json.RawMessage `json:"sessionPolicy"`
+	SessionPolicy SRSessionPolicy `json:"sessionPolicy"`
 	Expiration    *time.Time      `json:"expiration,omitempty"`
 	APIVersion    string          `json:"apiVersion,omitempty"`
 }
@@ -1230,7 +1254,8 @@ type SRMetric struct {
 	TotalDowntime time.Duration `json:"totalDowntime"`
 	LastOnline    time.Time     `json:"lastOnline"`
 	Online        bool          `json:"isOnline"`
-	Latency       LatencyStat   `json:"latency"`
+
+	Latency LatencyStat `json:"latency"`
 
 	// replication metrics across buckets roll up
 	ReplicatedSize int64 `json:"replicatedSize"`
@@ -1242,6 +1267,8 @@ type SRMetric struct {
 	XferStats map[replication.MetricName]replication.XferStats `json:"transferSummary"`
 	// MRFStats captures current backlog entries in the last 5 minutes
 	MRFStats replication.ReplMRFStats `json:"mrfStats"`
+	// DowntimeInfo captures the link information
+	DowntimeInfo DowntimeInfo `json:"downtimeInfo"`
 }
 
 // WorkerStat captures number of replication workers
@@ -1286,6 +1313,20 @@ type SRMetricsSummary struct {
 	Metrics map[string]SRMetric `json:"replMetrics"`
 	// uptime of node being queried for site replication metrics
 	Uptime int64 `json:"uptime"`
+	// represents the retry count
+	Retries Counter `json:"retries"`
+	// represents the error count
+	Errors Counter `json:"errors"`
+}
+
+// Counter denotes the counts
+type Counter struct {
+	// Counted last 1hr
+	Last1hr uint64 `json:"last1hr"`
+	// Counted last 1m
+	Last1m uint64 `json:"last1m"`
+	// Total count
+	Total uint64 `json:"total"`
 }
 
 // ReplProxyMetric holds stats for replication proxying
