@@ -1088,8 +1088,9 @@ type TLSCert struct {
 type MinioHealthInfo struct {
 	Error string `json:"error,omitempty"`
 
-	Config MinioConfig `json:"config,omitempty"`
-	Info   MinioInfo   `json:"info,omitempty"`
+	Config      MinioConfig   `json:"config,omitempty"`
+	Info        MinioInfo     `json:"info,omitempty"`
+	Replication *ReplDiagInfo `json:"replication,omitempty"`
 }
 
 // HealthInfo - MinIO cluster's health Info
@@ -1153,6 +1154,7 @@ const (
 	HealthDataTypeSysErrors   HealthDataType = "syserrors"
 	HealthDataTypeSysServices HealthDataType = "sysservices"
 	HealthDataTypeSysConfig   HealthDataType = "sysconfig"
+	HealthDataTypeReplication HealthDataType = "replication"
 )
 
 // HealthDataTypesMap - Map of Health datatypes
@@ -1168,6 +1170,7 @@ var HealthDataTypesMap = map[string]HealthDataType{
 	"syserrors":   HealthDataTypeSysErrors,
 	"sysservices": HealthDataTypeSysServices,
 	"sysconfig":   HealthDataTypeSysConfig,
+	"replication": HealthDataTypeReplication,
 }
 
 // HealthDataTypesList - List of health datatypes
@@ -1183,6 +1186,7 @@ var HealthDataTypesList = []HealthDataType{
 	HealthDataTypeSysErrors,
 	HealthDataTypeSysServices,
 	HealthDataTypeSysConfig,
+	HealthDataTypeReplication,
 }
 
 // HealthInfoVersionStruct - struct for health info version
