@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2015-2023 MinIO, Inc.
+// Copyright (c) 2015-2024 MinIO, Inc.
 //
 // This file is part of MinIO Object Storage stack
 //
@@ -73,6 +73,7 @@ func NewMetricsClientWithOptions(endpoint string, opts *Options) (*MetricsClient
 }
 
 // NewMetricsClient - instantiate minio metrics client honoring Prometheus format
+//
 // Deprecated: please use NewMetricsClientWithOptions
 func NewMetricsClient(endpoint string, accessKeyID, secretAccessKey string, secure bool) (*MetricsClient, error) {
 	return NewMetricsClientWithOptions(endpoint, &Options{
@@ -120,7 +121,7 @@ func (client *MetricsClient) executeGetRequest(ctx context.Context, reqData metr
 		return nil, err
 	}
 
-	v, err := client.creds.Get()
+	v, err := client.creds.GetWithContext(client.CredContext())
 	if err != nil {
 		return nil, err
 	}
@@ -164,6 +165,7 @@ func (client *MetricsClient) makeTargetURL(r metricsRequestData) (*url.URL, erro
 }
 
 // SetCustomTransport - set new custom transport.
+//
 // Deprecated: please use Options{Transport: tr} to provide custom transport.
 func (client *MetricsClient) SetCustomTransport(customHTTPTransport http.RoundTripper) {
 	// Set this to override default transport
@@ -184,3 +186,10 @@ func (client *MetricsClient) SetCustomTransport(customHTTPTransport http.RoundTr
 		client.httpClient.Transport = customHTTPTransport
 	}
 }
+
+// CredContext returns the context for fetching credentials
+func (client *MetricsClient) CredContext() *credentials.CredContext {
+	return &credentials.CredContext{
+		Client: client.httpClient,
+	}
+}
