@@ -50,16 +50,16 @@ func (a ARN) String() string {
 func ParseARN(s string) (*ARN, error) {
 	// ARN must be in the format of arn:minio:<Type>:<REGION>:<ID>:<remote-bucket>
 	if !strings.HasPrefix(s, "arn:minio:") {
-		return nil, fmt.Errorf("Invalid ARN %s", s)
+		return nil, fmt.Errorf("invalid ARN %s", s)
 	}
 
 	tokens := strings.Split(s, ":")
 	if len(tokens) != 6 {
-		return nil, fmt.Errorf("Invalid ARN %s", s)
+		return nil, fmt.Errorf("invalid ARN %s", s)
 	}
 
 	if tokens[4] == "" || tokens[5] == "" {
-		return nil, fmt.Errorf("Invalid ARN %s", s)
+		return nil, fmt.Errorf("invalid ARN %s", s)
 	}
 
 	return &ARN{
